@@ -4,15 +4,17 @@ library(Formula)
 library(abind)
 library(rstan)
 
-set_sampling_default  <- function(iter, warmup, chains, cores=1) {
-    options(OncoBayes2.MC.iter=iter, OncoBayes2.MC.warmup=warmup, OncoBayes2.MC.chains=chains, mc.cores=cores)
+set_sampling_default  <- function(iter, warmup, chains, cores=getOption("mc.cores", 1), save_warmup=FALSE) {
+    options(OncoBayes2.MC.iter=iter, OncoBayes2.MC.warmup=warmup, OncoBayes2.MC.chains=chains, mc.cores=cores, OncoBayes2.MC.save_warmup=save_warmup)
 }
 
 very_fast_sampling <- function() {
+    message("Tests running with very fast sampling")
     set_sampling_default(300, 150, 1, 1)
 }
 
 fake_sampling <- function() {
+    message("Tests running with fake sampling")
     set_sampling_default(4, 2, 1, 1)
 }
 
@@ -26,10 +28,12 @@ run_example <- function(example) {
     invisible(env)
 }
 
-fake_sampling()
+
 
 ## set up slim sampling in case we are on CRAN
 if (identical(Sys.getenv("NOT_CRAN"), "true")) {
     very_fast_sampling()
+} else {
+    fake_sampling()
 }
 
